@@ -65,9 +65,10 @@ with other DBs.
 
 use v5.12;
 
-package SQL::Steno v0.2.3;
+package SQL::Steno v0.2.4;
 
 use strict;
+use warnings;
 use Time::HiRes qw(gettimeofday tv_interval);
 
 binmode STDIN, ':utf8';
@@ -150,19 +151,19 @@ Queries
       '{($_[7] // "") ne "Sleep"}=show full processlist'],
 
 
-    [s => 'var,value   set @var = value',
+    [s => 'var;value   set @var = value',
       'set @$1=$2'],
 
-    [ss => 'var,value   set @var = "value"',
+    [ss => 'var;value   set @var = "value"',
       'set @$1=$"*"'],
 
-    [sd => 'var,value   set @var = cast("value" as date)',
+    [sd => 'var;value   set @var = cast("value" as date)',
       'set @$1=cast($"*" as date)'],
 
-    [sdt => 'var,value   set @var = cast("value" as datetime)',
+    [sdt => 'var;value   set @var = cast("value" as datetime)',
       'set @$1=cast($"*" as datetime)'],
 
-    [st => 'var,value   set @var = cast("value" as time)',
+    [st => 'var;value   set @var = cast("value" as time)',
       'set @$1=cast($"*" as time)'],
 
     [sy => '            set @a, @z   yesterday is between @a and @z  (see :baz)',
@@ -355,7 +356,7 @@ sub convert_Queries($$) {
     my $res = find $_[0], '&', '', %Queries;
     local $_ =  $_[1];
     &convert_table_column;
-    my @arg = split ',';
+    my @arg = split ';';
     return &$res( $_[0], @arg ) // '' if ref $res;
     my @rest;
     for my $i ( 1..@arg ) {
@@ -597,12 +598,13 @@ sub render_csv($;$$) {
 
 sub render_table($;$$) {
     my( $sth, $filter ) = @_;
-    my( $null, $crlf, $date ) =
+    my( $null, $crlf, $date, $time ) =
 	exists $_[2]{all} ?
-	('NULL', 1, 1) :
+	('NULL', 1, 1, 1) :
 	(exists $_[2]{NULL} ? 'NULL' : exists $_[2]{null} ? 'null' : 0,
 	 exists $_[2]{crlf},
-	 exists $_[2]{date})
+	 exists $_[2]{date},
+	 exists $_[2]{time})
 	if $_[2];
     $null ||= '\@';
     my @name = @{$sth->{NAME}};
@@ -618,10 +620,29 @@ sub render_table($;$$) {
 		$res1[$i] =~ s/\r\n/\\R/g unless $crlf;
 		$res1[$i] =~ s/([\t\n\r])/$esc{$1}/g;
 		no warnings 'uninitialized';
-		$res1[$i] =~ s/^(?:(0000-)00-00|(1970-)01-01)(?:( 00:)00:00)?$/$1$2$3/ or
-		    $res1[$i] =~ s/^(\d{4}-\d\d-\d\d )?(?:00:00:00|23:59:5(9))$/$1 . ($2 ? '24:' : '00:')/e or
-		    $res1[$i] =~ s/^((\d{4}-\d\d-\d\d )?\d\d:\d\d):00$/$1/
-		    unless $date;
+		unless( $date ) {
+		    if( $res1[$i] =~ s/^(\d{4}-)(\d\d)-0[01]([T ]\d\d:\d\d(?::\d\d(?:\.\d{3})?)?Z?)?$/$1/ ) {
+			$res1[$i] .= "$2-" if $2 > 1;
+			$res1[$i] .= $3 if $3;
+		    }
+		}
+		unless( $time ) {
+		    if( $res1[$i] =~ s/^(\d{4}-(?:\d\d-(?:\d\d)?)?[T ])?(\d\d):(\d\d)(?::(\d\d)(?:\.(\d{3}))?)?(Z?)$/$1/ ) {
+			$res1[$i] = $1 || '';
+			if( $2 == 23 && $3 == 59 && ($4 // 59) == 59 && ($5 // 999) == 999 ) {
+			    $res1[$i] .= "24:";
+			} elsif( $5 > 0 ) {
+			    $res1[$i] .= "$2:$3:$4.$5";
+			} elsif( $4 > 0 ) {
+			    $res1[$i] .= "$2:$3:$4";
+			} elsif( $3 > 0 ) {
+			    $res1[$i] .= "$2:$3";
+			} else {
+			    $res1[$i] .= "$2:";
+			}
+			$res1[$i] .= $6;
+		    }
+		}
 		utf8::decode $res1[$i];
 	    }
 	    $txt[$i] = 0 if @txt < $i;
@@ -767,9 +788,9 @@ order (i.e. C<&xyz> can return C</regexp/=literal sql> etc.):
 
 =over
 
-=item &query arg, ...
+=item &query arg; ...
 
-=item &query( arg, ... ) following text
+=item &query( arg; ... ) following text
 
 =item &{Perl code} following text
 
@@ -878,7 +899,10 @@ The known suffixes and their respective options are:
 
 =item C<.csv>
 
-CSV can take one of these options:
+This writes Comma Separated Values with one subtle trick: NULL and empty
+strings are distinguished by quoting the latter.  Some tools like Perl's file
+DB L<DBD::CSV> or rather its underlying L<Text::CSV_XS> can pick that up.  CSV
+can take one of these options:
 
 =over
 
@@ -914,7 +938,13 @@ Do not shorten C<\r\n> to C<\R>.
 
 =item date
 
-Output ISO dates and times fully instead of shortening them.
+Output ISO dates fully instead of shortening 0000-00-00 to 0000- and
+yyyy-01-01 to yyyy- or yyyy-mm-01 to yyyy-mm-.
+
+=item time
+
+Output times fully instead of shortening 23:59(:59) to 24: and hh:00(:00) to
+hh: or hh:mm(:00) to hh:mm.
 
 =item NULL
 
@@ -938,6 +968,7 @@ for it.
 =cut
 
 our $prompt = 'steno> ';
+our $contprompt = '...>  ';
 sub shell() {
     print STDERR $prompt;
     my $fh;
@@ -951,7 +982,7 @@ sub shell() {
 	    chomp;
 	} else {
 	    while( s/(?<!\\)((?:\\\\)*)\\(?=\n\Z)/$1/ ) {	# join continuation lines
-		print STDERR '...> ';
+		print STDERR $contprompt;
 		$_ .= <>;
 	    }
 	    s/\A\s+//;
